@@ -67,6 +67,9 @@
 #include <pi-dlp.h>
 #include <pi-version.h>
 
+#include <gpilotd/gnome-pilot-conduit.h>
+extern GnomePilotConduit *the_conduit;
+
 #define DEFAULT_CARD_NUM 0
 
 #define VERSION_STRING "malsync version 2.0.4"
@@ -133,7 +136,7 @@ static struct option long_options[] =
 #endif
 
 int sd = 0;
-static int verbose = 0;
+static int verbose;
 static int daemon_mode = 0;
 static int threeone = 0;
 static int lowres = 0;
@@ -145,9 +148,9 @@ static int32 getNextModifiedRecord(void * out, AGRecord ** record,
 static int32 getNextRecord(void * out, AGRecord ** record,
                            int32 *errCode);
 
-static int32 cmdTASK(void *out, int32 *returnErrorCode, char *currentTask,
+extern int32 cmdTASK(void *out, int32 *returnErrorCode, char *currentTask,
                      AGBool bufferable);
-static int32 cmdITEM(void *out, int32 *returnErrorCode,
+extern int32 cmdITEM(void *out, int32 *returnErrorCode,
                                    int32 currentItemNumber,
                                    int32 totalItemCount,
                                    char *currentItem);
@@ -780,7 +783,9 @@ AGUserConfig *getUserConfig(uint32 * pilotID)
     userConfigDBHandle = openUserConfigDatabase(&threeone);
 
     if (userConfigDBHandle) {
-        
+        if (verbose) {
+            fprintf (stderr, "Reading user config...\n");
+        }
         
         /* Retrieve device's idea of current userConfig. */
         *pilotID = readDeviceUserConfig(userConfigDBHandle,
@@ -791,6 +796,10 @@ AGUserConfig *getUserConfig(uint32 * pilotID)
         dlp_CloseDB(sd, userConfigDBHandle);
         
 
+    } else {
+        if (verbose) {
+            fprintf (stderr, "No user config, haha...\n");
+        }
     }
     return deviceUserConfig;
 }
@@ -848,8 +857,10 @@ doEndServer(PalmSyncInfo * pInfo, int32 *errCode)
         pInfo->commandProcessor = NULL;
     }
 }
+
+#if 0
 /*---------------------------------------------------------------------------*/
-static int32 
+int32 
 cmdTASK(void *out, int32 *returnErrorCode, char *currentTask, 
         AGBool bufferable)
 {
@@ -858,7 +869,7 @@ cmdTASK(void *out, int32 *returnErrorCode, char *currentTask,
     return AGCLIENT_CONTINUE;
 }
 /*---------------------------------------------------------------------------*/
-static int32 
+int32 
 cmdITEM(void *out, int32 *returnErrorCode, int32 currentItemNumber,
         int32 totalItemCount, char *currentItem)
 {
@@ -869,6 +880,8 @@ cmdITEM(void *out, int32 *returnErrorCode, int32 currentItemNumber,
     
     return AGCLIENT_CONTINUE;
 }
+#endif 
+
 /*---------------------------------------------------------------------------*/
 static int32 
 cmdDELETEDATABASE(void *out, int32 *returnErrorCode, char *dbname)
@@ -929,7 +942,7 @@ cmdGOODBYE(void *out, int32 *returnErrorCode, AGSyncStatus syncStatus,
         printf("doCmdAG_GOODBYE_CMD()\n");
 
     if (errorMessage)
-        printf("%s\n", errorMessage);
+        printf("MALsync %s\n", errorMessage);
     
     return AGCLIENT_CONTINUE;
 }
@@ -1231,7 +1244,6 @@ doClientProcessorLoop(PalmSyncInfo * pInfo, AGNetCtx *ctx)
             
             AGClientProcessorSync(pInfo->clientProcessor);
 
-
             cpResult = AGCLIENT_CONTINUE;
             while (AGCLIENT_CONTINUE == cpResult) {
                 cpResult = AGClientProcessorProcess(pInfo->clientProcessor);
@@ -1243,7 +1255,7 @@ doClientProcessorLoop(PalmSyncInfo * pInfo, AGNetCtx *ctx)
                 if (dlp_OpenConduit(sd)<0) {
                     fprintf(stderr, 
                             "Exiting on cancel, data not retrieved.\n");
-                    exit(1);
+                    cancelled = TRUE;
                 }
                 
             }
@@ -1252,10 +1264,13 @@ doClientProcessorLoop(PalmSyncInfo * pInfo, AGNetCtx *ctx)
             if(cpResult == AGCLIENT_ERR) {
 
                 char *msg = AGGetMsg(pInfo->clientProcessor->errStringId);
-                if (msg)
-                    fprintf(stderr,"%s\n", msg);
-                else
+                if (msg) {
+                    gnome_pilot_conduit_send_message (the_conduit, msg);
+                    fprintf(stderr,"MALsync message %s\n", msg);
+                } else {
+                    gnome_pilot_conduit_send_message (the_conduit, msg);
                     fprintf(stderr,"Unknown error\n");
+                }
                     
             }
 
@@ -1278,6 +1293,8 @@ doClientProcessorLoop(PalmSyncInfo * pInfo, AGNetCtx *ctx)
         
     }
 
+    fprintf (stderr, "cancelled = %s, verbose = %d\n", cancelled ? "true" : "false", verbose);
+
     return TRUE; /* success */
 }
 /*---------------------------------------------------------------------------*/
